from .ai import TOKEN_LIMIT
from .files import BLACKLISTED_FILES
from .format_specs import BITRATES_KBPS, DURATION_SECONDS_25MB

__all__ = ["BLACKLISTED_FILES", "BITRATES_KBPS", "DURATION_SECONDS_25MB", "TOKEN_LIMIT"]



# import os
# from pathlib import Path

# from bragir.config import CONFIG_FILE_PATH
# from bragir.tracing.logger import logger

# path = Path(CONFIG_FILE_PATH).expanduser()

# # if not os.path.isfile(path):
# #     logger.info(f"Config file not found at: {CONFIG_FILE_PATH}")

# #     logger.info(
# #         "Run the following command to create a new config file: `bragir config create`"
# #     )
# #     exit(1)
